# eric7.Plugins.CheckerPlugins.CodeStyleChecker.CodeStyleStatisticsDialog

Module implementing a dialog showing statistical data for the last code style checker run.

### Global Attributes

None

### Classes

CodeStyleStatisticsDialog | Class implementing a dialog showing statistical data for the last code style checker run.

### Functions

None

## CodeStyleStatisticsDialog

Class implementing a dialog showing statistical data for the last code style checker run.

### Derived from

QDialog, Ui_CodeStyleStatisticsDialog

### Class Attributes

None

### Class Methods

None

### Methods

CodeStyleStatisticsDialog | Constructor
__createItem | Private method to create an entry in the result list.

### Static Methods

None

#### CodeStyleStatisticsDialog (Constructor)

CodeStyleStatisticsDialog(statisticData, parent=None)

Constructor

statisticData (dict)
  dictionary with the statistical data
parent (QWidget)
  reference to the parent widget

#### CodeStyleStatisticsDialog.__createItem

__createItem(counts, msgCode, message)

Private method to create an entry in the result list.

counts (dict)
  dictionary containing the total and ignored occurrences of the issue
msgCode (str)
  code of a code style issue message
message (str)
  code style issue message to be shown

Up